@@ -1,7 +1,7 @@
 /* lock-test.c --- tests for the filesystem locking functions
  *
  * ====================================================================
- * Copyright (c) 2000-2004 CollabNet.  All rights reserved.
+ * Copyright (c) 2000-2004, 2008 CollabNet.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -19,6 +19,8 @@
 #include <apr_pools.h>
 #include <apr_time.h>
 
+#include "../svn_test.h"
+
 #include "svn_error.h"
 #include "svn_fs.h"
 
@@ -38,14 +40,14 @@ struct get_locks_baton_t
 };
 
 static svn_error_t *
-get_locks_callback(void *baton, 
-                   svn_lock_t *lock, 
+get_locks_callback(void *baton,
+                   svn_lock_t *lock,
                    apr_pool_t *pool)
 {
   struct get_locks_baton_t *b = baton;
   apr_pool_t *hash_pool = apr_hash_pool_get(b->locks);
   svn_string_t *lock_path = svn_string_create(lock->path, hash_pool);
-  apr_hash_set(b->locks, lock_path->data, lock_path->len, 
+  apr_hash_set(b->locks, lock_path->data, lock_path->len,
                svn_lock_dup(lock, hash_pool));
   return SVN_NO_ERROR;
 }
@@ -59,8 +61,8 @@ make_get_locks_baton(apr_pool_t *pool)
   baton->locks = apr_hash_make(pool);
   return baton;
 }
-     
-     
+
+
 /* And verification function(s). */
 
 static svn_error_t *
@@ -104,21 +106,22 @@ lock_only(const char **msg,
   svn_revnum_t newrev;
   svn_fs_access_t *access;
   svn_lock_t *mylock;
-  
+
   *msg = "lock only";
 
   if (msg_only)
     return SVN_NO_ERROR;
 
   /* Prepare a filesystem and a new txn. */
-  SVN_ERR(svn_test__create_fs(&fs, "test-repo-lock-only", 
-                              opts->fs_type, pool));
+  SVN_ERR(svn_test__create_fs(&fs, "test-repo-lock-only",
+                              opts, pool));
   SVN_ERR(svn_fs_begin_txn2(&txn, fs, 0, SVN_FS_TXN_CHECK_LOCKS, pool));
   SVN_ERR(svn_fs_txn_root(&txn_root, txn, pool));
 
   /* Create the greek tree and commit it. */
   SVN_ERR(svn_test__create_greek_tree(txn_root, pool));
   SVN_ERR(svn_fs_commit_txn(&conflict, &newrev, txn, pool));
+  SVN_TEST_ASSERT(SVN_IS_VALID_REVNUM(newrev));
 
   /* We are now 'bubba'. */
   SVN_ERR(svn_fs_create_access(&access, "bubba", pool));
@@ -150,21 +153,22 @@ lookup_lock_by_path(const char **msg,
   svn_revnum_t newrev;
   svn_fs_access_t *access;
   svn_lock_t *mylock, *somelock;
-  
+
   *msg = "lookup lock by path";
 
   if (msg_only)
     return SVN_NO_ERROR;
 
   /* Prepare a filesystem and a new txn. */
-  SVN_ERR(svn_test__create_fs(&fs, "test-repo-lookup-lock-by-path", 
-                              opts->fs_type, pool));
+  SVN_ERR(svn_test__create_fs(&fs, "test-repo-lookup-lock-by-path",
+                              opts, pool));
   SVN_ERR(svn_fs_begin_txn2(&txn, fs, 0, SVN_FS_TXN_CHECK_LOCKS, pool));
   SVN_ERR(svn_fs_txn_root(&txn_root, txn, pool));
 
   /* Create the greek tree and commit it. */
   SVN_ERR(svn_test__create_greek_tree(txn_root, pool));
   SVN_ERR(svn_fs_commit_txn(&conflict, &newrev, txn, pool));
+  SVN_TEST_ASSERT(SVN_IS_VALID_REVNUM(newrev));
 
   /* We are now 'bubba'. */
   SVN_ERR(svn_fs_create_access(&access, "bubba", pool));
@@ -207,14 +211,15 @@ attach_lock(const char **msg,
     return SVN_NO_ERROR;
 
   /* Prepare a filesystem and a new txn. */
-  SVN_ERR(svn_test__create_fs(&fs, "test-repo-attach-lock", 
-                              opts->fs_type, pool));
+  SVN_ERR(svn_test__create_fs(&fs, "test-repo-attach-lock",
+                              opts, pool));
   SVN_ERR(svn_fs_begin_txn2(&txn, fs, 0, SVN_FS_TXN_CHECK_LOCKS, pool));
   SVN_ERR(svn_fs_txn_root(&txn_root, txn, pool));
 
   /* Create the greek tree and commit it. */
   SVN_ERR(svn_test__create_greek_tree(txn_root, pool));
   SVN_ERR(svn_fs_commit_txn(&conflict, &newrev, txn, pool));
+  SVN_TEST_ASSERT(SVN_IS_VALID_REVNUM(newrev));
 
   /* We are now 'bubba'. */
   SVN_ERR(svn_fs_create_access(&access, "bubba", pool));
@@ -266,14 +271,15 @@ get_locks(const char **msg,
     return SVN_NO_ERROR;
 
   /* Prepare a filesystem and a new txn. */
-  SVN_ERR(svn_test__create_fs(&fs, "test-repo-get-locks", 
-                              opts->fs_type, pool));
+  SVN_ERR(svn_test__create_fs(&fs, "test-repo-get-locks",
+                              opts, pool));
   SVN_ERR(svn_fs_begin_txn2(&txn, fs, 0, SVN_FS_TXN_CHECK_LOCKS, pool));
   SVN_ERR(svn_fs_txn_root(&txn_root, txn, pool));
 
   /* Create the greek tree and commit it. */
   SVN_ERR(svn_test__create_greek_tree(txn_root, pool));
   SVN_ERR(svn_fs_commit_txn(&conflict, &newrev, txn, pool));
+  SVN_TEST_ASSERT(SVN_IS_VALID_REVNUM(newrev));
 
   /* We are now 'bubba'. */
   SVN_ERR(svn_fs_create_access(&access, "bubba", pool));
@@ -281,12 +287,12 @@ get_locks(const char **msg,
 
   /* Lock our paths; verify from "/". */
   {
-    static const char *expected_paths[] = { 
-      "/A/D/G/pi", 
-      "/A/D/G/rho", 
+    static const char *expected_paths[] = {
+      "/A/D/G/pi",
+      "/A/D/G/rho",
       "/A/D/G/tau",
-      "/A/D/H/psi", 
-      "/A/D/H/chi", 
+      "/A/D/H/psi",
+      "/A/D/H/chi",
       "/A/D/H/omega",
       "/A/B/E/alpha",
       "/A/B/E/beta",
@@ -294,7 +300,7 @@ get_locks(const char **msg,
     num_expected_paths = sizeof(expected_paths) / sizeof(const char *);
     for (i = 0; i < num_expected_paths; i++)
       {
-        SVN_ERR(svn_fs_lock(&mylock, fs, expected_paths[i], NULL, "", 0, 0, 
+        SVN_ERR(svn_fs_lock(&mylock, fs, expected_paths[i], NULL, "", 0, 0,
                             SVN_INVALID_REVNUM, FALSE, pool));
       }
     get_locks_baton = make_get_locks_baton(pool);
@@ -306,7 +312,7 @@ get_locks(const char **msg,
 
   /* Verify from "/A/B". */
   {
-    static const char *expected_paths[] = { 
+    static const char *expected_paths[] = {
       "/A/B/E/alpha",
       "/A/B/E/beta",
     };
@@ -320,12 +326,12 @@ get_locks(const char **msg,
 
   /* Verify from "/A/D". */
   {
-    static const char *expected_paths[] = { 
-      "/A/D/G/pi", 
-      "/A/D/G/rho", 
+    static const char *expected_paths[] = {
+      "/A/D/G/pi",
+      "/A/D/G/rho",
       "/A/D/G/tau",
-      "/A/D/H/psi", 
-      "/A/D/H/chi", 
+      "/A/D/H/psi",
+      "/A/D/H/chi",
       "/A/D/H/omega",
     };
     num_expected_paths = sizeof(expected_paths) / sizeof(const char *);
@@ -338,9 +344,9 @@ get_locks(const char **msg,
 
   /* Verify from "/A/D/G". */
   {
-    static const char *expected_paths[] = { 
-      "/A/D/G/pi", 
-      "/A/D/G/rho", 
+    static const char *expected_paths[] = {
+      "/A/D/G/pi",
+      "/A/D/G/rho",
       "/A/D/G/tau",
     };
     num_expected_paths = sizeof(expected_paths) / sizeof(const char *);
@@ -350,10 +356,10 @@ get_locks(const char **msg,
     SVN_ERR(verify_matching_lock_paths(get_locks_baton, expected_paths,
                                        num_expected_paths, pool));
   }
-                                    
+
   /* Verify from "/A/D/H/omega". */
   {
-    static const char *expected_paths[] = { 
+    static const char *expected_paths[] = {
       "/A/D/H/omega",
     };
     num_expected_paths = sizeof(expected_paths) / sizeof(const char *);
@@ -394,21 +400,22 @@ basic_lock(const char **msg,
   svn_revnum_t newrev;
   svn_fs_access_t *access;
   svn_lock_t *mylock, *somelock;
-  
+
   *msg = "basic locking";
 
   if (msg_only)
     return SVN_NO_ERROR;
 
   /* Prepare a filesystem and a new txn. */
-  SVN_ERR(svn_test__create_fs(&fs, "test-repo-basic-lock", 
-                              opts->fs_type, pool));
+  SVN_ERR(svn_test__create_fs(&fs, "test-repo-basic-lock",
+                              opts, pool));
   SVN_ERR(svn_fs_begin_txn2(&txn, fs, 0, SVN_FS_TXN_CHECK_LOCKS, pool));
   SVN_ERR(svn_fs_txn_root(&txn_root, txn, pool));
 
   /* Create the greek tree and commit it. */
   SVN_ERR(svn_test__create_greek_tree(txn_root, pool));
   SVN_ERR(svn_fs_commit_txn(&conflict, &newrev, txn, pool));
+  SVN_TEST_ASSERT(SVN_IS_VALID_REVNUM(newrev));
 
   /* We are now 'bubba'. */
   SVN_ERR(svn_fs_create_access(&access, "bubba", pool));
@@ -423,7 +430,7 @@ basic_lock(const char **msg,
   if ((! somelock) || (strcmp(somelock->token, mylock->token) != 0))
     return svn_error_create(SVN_ERR_TEST_FAILED, NULL,
                             "Couldn't look up a lock by pathname.");
-    
+
   /* Unlock /A/D/G/rho, and verify that it's gone. */
   SVN_ERR(svn_fs_unlock(fs, mylock->path, mylock->token, 0, pool));
   SVN_ERR(svn_fs_get_lock(&somelock, fs, "/A/D/G/rho", pool));
@@ -459,14 +466,15 @@ lock_credentials(const char **msg,
     return SVN_NO_ERROR;
 
   /* Prepare a filesystem and a new txn. */
-  SVN_ERR(svn_test__create_fs(&fs, "test-repo-lock-credentials", 
-                              opts->fs_type, pool));
+  SVN_ERR(svn_test__create_fs(&fs, "test-repo-lock-credentials",
+                              opts, pool));
   SVN_ERR(svn_fs_begin_txn2(&txn, fs, 0, SVN_FS_TXN_CHECK_LOCKS, pool));
   SVN_ERR(svn_fs_txn_root(&txn_root, txn, pool));
 
   /* Create the greek tree and commit it. */
   SVN_ERR(svn_test__create_greek_tree(txn_root, pool));
   SVN_ERR(svn_fs_commit_txn(&conflict, &newrev, txn, pool));
+  SVN_TEST_ASSERT(SVN_IS_VALID_REVNUM(newrev));
 
   /* We are now 'bubba'. */
   SVN_ERR(svn_fs_create_access(&access, "bubba", pool));
@@ -490,20 +498,22 @@ lock_credentials(const char **msg,
 
   /* Try to commit the file change.  Should fail, because we're nobody. */
   err = svn_fs_commit_txn(&conflict, &newrev, txn, pool);
+  SVN_TEST_ASSERT(! SVN_IS_VALID_REVNUM(newrev));
   if (! err)
-    return svn_error_create 
+    return svn_error_create
       (SVN_ERR_TEST_FAILED, NULL,
        "Uhoh, able to commit locked file without any fs username.");
   svn_error_clear(err);
-    
+
   /* We are now 'hortense'. */
   SVN_ERR(svn_fs_create_access(&access, "hortense", pool));
   SVN_ERR(svn_fs_set_access(fs, access));
 
   /* Try to commit the file change.  Should fail, because we're 'hortense'. */
   err = svn_fs_commit_txn(&conflict, &newrev, txn, pool);
+  SVN_TEST_ASSERT(! SVN_IS_VALID_REVNUM(newrev));
   if (! err)
-    return svn_error_create 
+    return svn_error_create
       (SVN_ERR_TEST_FAILED, NULL,
        "Uhoh, able to commit locked file as non-owner.");
   svn_error_clear(err);
@@ -511,20 +521,22 @@ lock_credentials(const char **msg,
   /* Be 'bubba' again. */
   SVN_ERR(svn_fs_create_access(&access, "bubba", pool));
   SVN_ERR(svn_fs_set_access(fs, access));
-  
+
   /* Try to commit the file change.  Should fail, because there's no token. */
   err = svn_fs_commit_txn(&conflict, &newrev, txn, pool);
+  SVN_TEST_ASSERT(! SVN_IS_VALID_REVNUM(newrev));
   if (! err)
-    return svn_error_create 
+    return svn_error_create
       (SVN_ERR_TEST_FAILED, NULL,
        "Uhoh, able to commit locked file with no lock token.");
   svn_error_clear(err);
-  
+
   /* Push the proper lock-token into the fs access context. */
   SVN_ERR(svn_fs_access_add_lock_token(access, mylock->token));
 
   /* Commit should now succeed. */
   SVN_ERR(svn_fs_commit_txn(&conflict, &newrev, txn, pool));
+  SVN_TEST_ASSERT(SVN_IS_VALID_REVNUM(newrev));
 
   return SVN_NO_ERROR;
 }
@@ -556,14 +568,15 @@ final_lock_check(const char **msg,
     return SVN_NO_ERROR;
 
   /* Prepare a filesystem and a new txn. */
-  SVN_ERR(svn_test__create_fs(&fs, "test-repo-final-lock-check", 
-                              opts->fs_type, pool));
+  SVN_ERR(svn_test__create_fs(&fs, "test-repo-final-lock-check",
+                              opts, pool));
   SVN_ERR(svn_fs_begin_txn2(&txn, fs, 0, SVN_FS_TXN_CHECK_LOCKS, pool));
   SVN_ERR(svn_fs_txn_root(&txn_root, txn, pool));
 
   /* Create the greek tree and commit it. */
   SVN_ERR(svn_test__create_greek_tree(txn_root, pool));
   SVN_ERR(svn_fs_commit_txn(&conflict, &newrev, txn, pool));
+  SVN_TEST_ASSERT(SVN_IS_VALID_REVNUM(newrev));
 
   /* Make a new transaction and delete "/A" */
   SVN_ERR(svn_fs_begin_txn2(&txn, fs, newrev, SVN_FS_TXN_CHECK_LOCKS, pool));
@@ -582,8 +595,9 @@ final_lock_check(const char **msg,
   /* Try to commit the transaction.  Should fail, because a child of
      the deleted directory is locked by someone else. */
   err = svn_fs_commit_txn(&conflict, &newrev, txn, pool);
+  SVN_TEST_ASSERT(! SVN_IS_VALID_REVNUM(newrev));
   if (! err)
-    return svn_error_create 
+    return svn_error_create
       (SVN_ERR_TEST_FAILED, NULL,
        "Uhoh, able to commit dir deletion when a child is locked.");
   svn_error_clear(err);
@@ -592,6 +606,7 @@ final_lock_check(const char **msg,
   SVN_ERR(svn_fs_set_access(fs, access));
   SVN_ERR(svn_fs_access_add_lock_token(access, mylock->token));
   SVN_ERR(svn_fs_commit_txn(&conflict, &newrev, txn, pool));
+  SVN_TEST_ASSERT(SVN_IS_VALID_REVNUM(newrev));
 
   return SVN_NO_ERROR;
 }
@@ -620,14 +635,15 @@ lock_dir_propchange(const char **msg,
     return SVN_NO_ERROR;
 
   /* Prepare a filesystem and a new txn. */
-  SVN_ERR(svn_test__create_fs(&fs, "test-repo-lock-dir-propchange", 
-                              opts->fs_type, pool));
+  SVN_ERR(svn_test__create_fs(&fs, "test-repo-lock-dir-propchange",
+                              opts, pool));
   SVN_ERR(svn_fs_begin_txn2(&txn, fs, 0, SVN_FS_TXN_CHECK_LOCKS, pool));
   SVN_ERR(svn_fs_txn_root(&txn_root, txn, pool));
 
   /* Create the greek tree and commit it. */
   SVN_ERR(svn_test__create_greek_tree(txn_root, pool));
   SVN_ERR(svn_fs_commit_txn(&conflict, &newrev, txn, pool));
+  SVN_TEST_ASSERT(SVN_IS_VALID_REVNUM(newrev));
 
   /* Become 'bubba' and lock "/A/D/G/rho". */
   SVN_ERR(svn_fs_create_access(&access, "bubba", pool));
@@ -648,6 +664,7 @@ lock_dir_propchange(const char **msg,
   /* Commit should succeed;  this means we're doing a non-recursive
      lock-check on directory, rather than a recursive one.  */
   SVN_ERR(svn_fs_commit_txn(&conflict, &newrev, txn, pool));
+  SVN_TEST_ASSERT(SVN_IS_VALID_REVNUM(newrev));
 
   return SVN_NO_ERROR;
 }
@@ -677,14 +694,15 @@ lock_name_reservation(const char **msg,
     return SVN_NO_ERROR;
 
   /* Prepare a filesystem and a new txn. */
-  SVN_ERR(svn_test__create_fs(&fs, "test-repo-lock-name-reservation", 
-                              opts->fs_type, pool));
+  SVN_ERR(svn_test__create_fs(&fs, "test-repo-lock-name-reservation",
+                              opts, pool));
   SVN_ERR(svn_fs_begin_txn2(&txn, fs, 0, SVN_FS_TXN_CHECK_LOCKS, pool));
   SVN_ERR(svn_fs_txn_root(&txn_root, txn, pool));
 
   /* Create the greek tree and commit it. */
   SVN_ERR(svn_test__create_greek_tree(txn_root, pool));
   SVN_ERR(svn_fs_commit_txn(&conflict, &newrev, txn, pool));
+  SVN_TEST_ASSERT(SVN_IS_VALID_REVNUM(newrev));
 
   /* Become 'bubba' and lock imaginary path  "/A/D/G2/blooga". */
   SVN_ERR(svn_fs_create_access(&access, "bubba", pool));
@@ -704,11 +722,11 @@ lock_name_reservation(const char **msg,
   SVN_ERR(svn_fs_revision_root(&rev_root, fs, 1, pool));
   err = svn_fs_copy(rev_root, "/A/D/G", txn_root, "/A/D/G2", pool);
   if (! err)
-    return svn_error_create 
+    return svn_error_create
       (SVN_ERR_TEST_FAILED, NULL,
        "Uhoh, copy succeeded when path within target was locked.");
   svn_error_clear(err);
-   
+
   return SVN_NO_ERROR;
 }
 
@@ -736,8 +754,8 @@ directory_locks_kinda(const char **msg,
     return SVN_NO_ERROR;
 
   /* Prepare a filesystem and a new txn. */
-  SVN_ERR(svn_test__create_fs(&fs, "test-repo-directory-locks-kinda", 
-                              opts->fs_type, pool));
+  SVN_ERR(svn_test__create_fs(&fs, "test-repo-directory-locks-kinda",
+                              opts, pool));
   SVN_ERR(svn_fs_begin_txn2(&txn, fs, 0, SVN_FS_TXN_CHECK_LOCKS, pool));
   SVN_ERR(svn_fs_txn_root(&txn_root, txn, pool));
 
@@ -748,8 +766,8 @@ directory_locks_kinda(const char **msg,
   /*** Lock some various, non-existent, yet dir-name-spacily
        overlapping paths; verify. ***/
   {
-    static const char *expected_paths[] = { 
-      "/Program Files/Tigris.org/Subversion", 
+    static const char *expected_paths[] = {
+      "/Program Files/Tigris.org/Subversion",
       "/Program Files/Tigris.org",
       "/Stuff/Junk/Fluff",
       "/Program Files",
@@ -759,7 +777,7 @@ directory_locks_kinda(const char **msg,
     /* Lock all paths under /A/D/G. */
     for (i = 0; i < num_expected_paths; i++)
       {
-        SVN_ERR(svn_fs_lock(&mylock, fs, expected_paths[i], NULL, "", 0, 0, 
+        SVN_ERR(svn_fs_lock(&mylock, fs, expected_paths[i], NULL, "", 0, 0,
                             SVN_INVALID_REVNUM, FALSE, pool));
       }
     get_locks_baton = make_get_locks_baton(pool);
@@ -771,14 +789,14 @@ directory_locks_kinda(const char **msg,
 
   /*** Now unlock a "middle directory" ***/
   {
-    static const char *expected_paths[] = { 
-      "/Program Files/Tigris.org/Subversion", 
+    static const char *expected_paths[] = {
+      "/Program Files/Tigris.org/Subversion",
       "/Stuff/Junk/Fluff",
       "/Program Files",
     };
     num_expected_paths = sizeof(expected_paths) / sizeof(const char *);
 
-    SVN_ERR(svn_fs_unlock(fs, "/Program Files/Tigris.org", NULL, 
+    SVN_ERR(svn_fs_unlock(fs, "/Program Files/Tigris.org", NULL,
                           TRUE, pool));
     get_locks_baton = make_get_locks_baton(pool);
     SVN_ERR(svn_fs_get_locks(fs, "/", get_locks_callback,
@@ -814,14 +832,15 @@ lock_expiration(const char **msg,
     return SVN_NO_ERROR;
 
   /* Prepare a filesystem and a new txn. */
-  SVN_ERR(svn_test__create_fs(&fs, "test-repo-lock-expiration", 
-                              opts->fs_type, pool));
+  SVN_ERR(svn_test__create_fs(&fs, "test-repo-lock-expiration",
+                              opts, pool));
   SVN_ERR(svn_fs_begin_txn2(&txn, fs, 0, SVN_FS_TXN_CHECK_LOCKS, pool));
   SVN_ERR(svn_fs_txn_root(&txn_root, txn, pool));
 
   /* Create the greek tree and commit it. */
   SVN_ERR(svn_test__create_greek_tree(txn_root, pool));
   SVN_ERR(svn_fs_commit_txn(&conflict, &newrev, txn, pool));
+  SVN_TEST_ASSERT(SVN_IS_VALID_REVNUM(newrev));
 
   /* Make a new transaction and change rho. */
   SVN_ERR(svn_fs_begin_txn2(&txn, fs, newrev, SVN_FS_TXN_CHECK_LOCKS, pool));
@@ -840,12 +859,13 @@ lock_expiration(const char **msg,
 
   /* Become nobody. */
   SVN_ERR(svn_fs_set_access(fs, NULL));
-  
+
   /* Try to commit.  Should fail because we're 'nobody', and the lock
      hasn't expired yet. */
   err = svn_fs_commit_txn(&conflict, &newrev, txn, pool);
+  SVN_TEST_ASSERT(! SVN_IS_VALID_REVNUM(newrev));
   if (! err)
-    return svn_error_create 
+    return svn_error_create
       (SVN_ERR_TEST_FAILED, NULL,
        "Uhoh, able to commit a file that has a non-expired lock.");
   svn_error_clear(err);
@@ -880,6 +900,7 @@ lock_expiration(const char **msg,
   }
 
   SVN_ERR(svn_fs_commit_txn(&conflict, &newrev, txn, pool));
+  SVN_TEST_ASSERT(SVN_IS_VALID_REVNUM(newrev));
 
   return SVN_NO_ERROR;
 }
@@ -905,14 +926,15 @@ lock_break_steal_refresh(const char **msg,
     return SVN_NO_ERROR;
 
   /* Prepare a filesystem and a new txn. */
-  SVN_ERR(svn_test__create_fs(&fs, "test-repo-steal-refresh", 
-                              opts->fs_type, pool));
+  SVN_ERR(svn_test__create_fs(&fs, "test-repo-steal-refresh",
+                              opts, pool));
   SVN_ERR(svn_fs_begin_txn2(&txn, fs, 0, SVN_FS_TXN_CHECK_LOCKS, pool));
   SVN_ERR(svn_fs_txn_root(&txn_root, txn, pool));
 
   /* Create the greek tree and commit it. */
   SVN_ERR(svn_test__create_greek_tree(txn_root, pool));
   SVN_ERR(svn_fs_commit_txn(&conflict, &newrev, txn, pool));
+  SVN_TEST_ASSERT(SVN_IS_VALID_REVNUM(newrev));
 
   /* Become 'bubba' and lock "/A/D/G/rho". */
   SVN_ERR(svn_fs_create_access(&access, "bubba", pool));
@@ -937,13 +959,13 @@ lock_break_steal_refresh(const char **msg,
   if (strcmp(somelock->owner, mylock->owner) != 0)
     return svn_error_create(SVN_ERR_TEST_FAILED, NULL,
                             "Made a lock, but we don't seem to own it.");
-  
+
   /* As bubba, steal hortense's lock, creating a new one that expires. */
   SVN_ERR(svn_fs_create_access(&access, "bubba", pool));
   SVN_ERR(svn_fs_set_access(fs, access));
   SVN_ERR(svn_fs_lock(&mylock, fs, "/A/D/G/rho", NULL, "", 0,
                       apr_time_now() + apr_time_from_sec(300), /* 5 min. */
-                      SVN_INVALID_REVNUM, 
+                      SVN_INVALID_REVNUM,
                       TRUE /* FORCE STEAL */,
                       pool));
   SVN_ERR(svn_fs_get_lock(&somelock, fs, "/A/D/G/rho", pool));
@@ -953,17 +975,17 @@ lock_break_steal_refresh(const char **msg,
   if (! somelock->expiration_date)
     return svn_error_create(SVN_ERR_TEST_FAILED, NULL,
                             "Made expiring lock, but seems not to expire.");
-    
+
   /* Refresh the lock, so that it never expires. */
-  SVN_ERR(svn_fs_lock(&somelock, fs, somelock->path, somelock->token, 
+  SVN_ERR(svn_fs_lock(&somelock, fs, somelock->path, somelock->token,
                       somelock->comment, 0, 0,
-                      SVN_INVALID_REVNUM, 
+                      SVN_INVALID_REVNUM,
                       TRUE /* FORCE STEAL */,
                       pool));
   SVN_ERR(svn_fs_get_lock(&somelock, fs, "/A/D/G/rho", pool));
   if (somelock->expiration_date)
     return svn_error_create(SVN_ERR_TEST_FAILED, NULL,
-                            "Made non-expirirng lock, but it expires.");  
+                            "Made non-expirirng lock, but it expires.");
 
   return SVN_NO_ERROR;
 }
@@ -985,21 +1007,22 @@ lock_out_of_date(const char **msg,
   svn_fs_access_t *access;
   svn_lock_t *mylock;
   svn_error_t *err;
-  
+
   *msg = "check out-of-dateness before locking";
 
   if (msg_only)
     return SVN_NO_ERROR;
 
   /* Prepare a filesystem and a new txn. */
-  SVN_ERR(svn_test__create_fs(&fs, "test-repo-lock-out-of-date", 
-                              opts->fs_type, pool));
+  SVN_ERR(svn_test__create_fs(&fs, "test-repo-lock-out-of-date",
+                              opts, pool));
   SVN_ERR(svn_fs_begin_txn2(&txn, fs, 0, SVN_FS_TXN_CHECK_LOCKS, pool));
   SVN_ERR(svn_fs_txn_root(&txn_root, txn, pool));
 
   /* Create the greek tree and commit it. */
   SVN_ERR(svn_test__create_greek_tree(txn_root, pool));
   SVN_ERR(svn_fs_commit_txn(&conflict, &newrev, txn, pool));
+  SVN_TEST_ASSERT(SVN_IS_VALID_REVNUM(newrev));
 
   /* Commit a small change to /A/D/G/rho, creating revision 2. */
   SVN_ERR(svn_fs_begin_txn2(&txn, fs, newrev, SVN_FS_TXN_CHECK_LOCKS, pool));
@@ -1007,7 +1030,8 @@ lock_out_of_date(const char **msg,
   SVN_ERR(svn_test__set_file_contents(txn_root, "/A/D/G/rho",
                                       "new contents", pool));
   SVN_ERR(svn_fs_commit_txn(&conflict, &newrev, txn, pool));
-  
+  SVN_TEST_ASSERT(SVN_IS_VALID_REVNUM(newrev));
+
   /* We are now 'bubba'. */
   SVN_ERR(svn_fs_create_access(&access, "bubba", pool));
   SVN_ERR(svn_fs_set_access(fs, access));
@@ -1015,24 +1039,24 @@ lock_out_of_date(const char **msg,
   /* Try to lock /A/D/G/rho, but claim that we still have r1 of the file. */
   err = svn_fs_lock(&mylock, fs, "/A/D/G/rho", NULL, "", 0, 0, 1, FALSE, pool);
   if (! err)
-    return svn_error_create 
+    return svn_error_create
       (SVN_ERR_TEST_FAILED, NULL,
        "Uhoh, able to lock an out-of-date file.");
   svn_error_clear(err);
 
   /* Attempt lock again, this time claiming to have r2. */
-  SVN_ERR(svn_fs_lock(&mylock, fs, "/A/D/G/rho", NULL, "", 0, 
+  SVN_ERR(svn_fs_lock(&mylock, fs, "/A/D/G/rho", NULL, "", 0,
                       0, 2, FALSE, pool));
 
   /* 'Refresh' the lock, claiming to have r1... should fail. */
-  err = svn_fs_lock(&mylock, fs, mylock->path, 
+  err = svn_fs_lock(&mylock, fs, mylock->path,
                     mylock->token, mylock->comment, 0,
                     apr_time_now() + apr_time_from_sec(50),
                     1,
                     TRUE /* FORCE STEAL */,
                     pool);
   if (! err)
-    return svn_error_create 
+    return svn_error_create
       (SVN_ERR_TEST_FAILED, NULL,
        "Uhoh, able to refresh a lock on an out-of-date file.");
   svn_error_clear(err);
